@@ -5,7 +5,7 @@ package DD;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-08-08'; # DATE
 our $DIST = 'DD'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT = qw(dd dd_warn dd_die dmp);
@@ -51,6 +51,12 @@ sub _doit {
         elsif ($_action eq 'dd_warn') { warn   Data::Dumper::Dumper(@_); return @_ }
         elsif ($_action eq 'dd_die' ) { die    Data::Dumper::Dumper(@_)            }
         elsif ($_action eq 'dmp'    ) { return Data::Dumper::Dumper(@_)            }
+    } elsif ($BACKEND eq 'Data::Dumper::Compact') {
+        require Data::Dumper::Compact;
+        if    ($_action eq 'dd'     ) { print  Data::Dumper::Compact->new()->dump(\@_); return @_ }
+        elsif ($_action eq 'dd_warn') { warn   Data::Dumper::Compact->new()->dump(\@_); return @_ }
+        elsif ($_action eq 'dd_die' ) { die    Data::Dumper::Compact->new()->dump(\@_)            }
+        elsif ($_action eq 'dmp'    ) { return Data::Dumper::Compact->new()->dump(\@_)            }
     } elsif ($BACKEND eq 'Data::Format::Pretty::Console') {
         require Data::Format::Pretty::Console;
         if    ($_action eq 'dd'     ) { print  Data::Format::Pretty::Console::format_pretty(\@_); return @_ }
@@ -136,7 +142,7 @@ DD - Dump data structure for debugging
 
 =head1 VERSION
 
-This document describes version 0.005 of DD (from Perl distribution DD), released on 2019-08-08.
+This document describes version 0.006 of DD (from Perl distribution DD), released on 2019-08-08.
 
 =head1 SYNOPSIS
 
@@ -188,7 +194,11 @@ See also: L<PHP::Serialization>.
 
 =item * L<Data::Dumper>
 
-A core module.
+Optional dependency. A core module.
+
+=item * L<Data::Dumper::Compact>
+
+Optional dependency.
 
 =item * L<Data::Format::Pretty::Console>
 
